Skip to contents

[Deprecated]

This function was deprecated because it was no longer required by analysts.

Usage

add_rows2(..., id = NULL)

Arguments

...

Other parameters to parse to function.

id

Default NULL

Value

SAS labelled dataframe

Details

Almost identical to the original dplyr::add_row but also looks for format.sas attribute which haven provides when loading as SAS dataset.

Created by PV (2023).