Details
Almost identical to the original dplyr::add_row but also looks for format.sas attribute which haven provides when loading as SAS dataset.
Created by PV (2023).
Almost identical to the original dplyr::add_row but also looks for format.sas attribute which haven provides when loading as SAS dataset.
Created by PV (2023).